@@ -1,14 +1,11 @@
-import abc
 from itertools import repeat
 from typing import List, Optional, Dict
 
-import six
 from conditional import conditional
 from django.core.checks import Error
 from django.core.exceptions import ValidationError
 from django.db import transaction, models, IntegrityError, connections
 from django.db.models import SlugField
-from django.db.models.base import ModelBase
 from django.utils.text import slugify
 
 from model_clone.apps import ModelCloneConfig
@@ -20,11 +17,7 @@ from model_clone.utils import (
 )
 
 
-class CloneMetaClass(abc.ABCMeta, ModelBase):
-    pass
-
-
-class CloneMixin(six.with_metaclass(CloneMetaClass)):
+class CloneMixin(object):
     """
     CloneMixin mixin to duplicate an object using the model cls.
 
